You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beam.apache.org by lo...@apache.org on 2022/06/14 16:49:19 UTC

[beam] branch master updated: Update references to Jira to GH for the Go label (#21830)

This is an automated email from the ASF dual-hosted git repository.

lostluck pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/beam.git


The following commit(s) were added to refs/heads/master by this push:
     new b91b16fcd8e Update references to Jira to GH for the Go label (#21830)
b91b16fcd8e is described below

commit b91b16fcd8e4c15f493f2e47b2eedbbd2b260e66
Author: Danny McCormick <da...@google.com>
AuthorDate: Tue Jun 14 12:49:13 2022 -0400

    Update references to Jira to GH for the Go label (#21830)
---
 sdks/go/container/boot.go                                |  2 +-
 sdks/go/pkg/beam/artifact/materialize.go                 |  4 ++--
 sdks/go/pkg/beam/core/graph/coder/coder.go               |  4 ++--
 sdks/go/pkg/beam/core/graph/coder/row.go                 |  2 +-
 sdks/go/pkg/beam/core/graph/coder/row_test.go            |  2 +-
 sdks/go/pkg/beam/core/graph/mtime/time.go                |  2 +-
 sdks/go/pkg/beam/core/runtime/exec/coder_test.go         |  2 +-
 sdks/go/pkg/beam/core/runtime/exec/cogbk.go              |  2 +-
 sdks/go/pkg/beam/core/runtime/exec/combine.go            |  2 +-
 sdks/go/pkg/beam/core/runtime/exec/datasource.go         |  4 ++--
 sdks/go/pkg/beam/core/runtime/exec/dynsplit_test.go      |  2 +-
 sdks/go/pkg/beam/core/runtime/exec/sdf.go                |  4 ++--
 sdks/go/pkg/beam/core/runtime/exec/translate.go          |  2 +-
 sdks/go/pkg/beam/core/runtime/graphx/coder.go            |  8 ++++----
 sdks/go/pkg/beam/core/runtime/graphx/cogbk.go            |  2 +-
 sdks/go/pkg/beam/core/runtime/graphx/dataflow.go         |  4 ++--
 sdks/go/pkg/beam/core/runtime/graphx/translate.go        |  6 +++---
 sdks/go/pkg/beam/core/runtime/harness/datamgr.go         |  2 +-
 sdks/go/pkg/beam/core/runtime/harness/monitoring.go      |  2 +-
 sdks/go/pkg/beam/core/util/jsonx/jsonx.go                |  2 +-
 sdks/go/pkg/beam/io/textio/textio.go                     |  2 +-
 sdks/go/pkg/beam/io/xlang/kafkaio/kafka.go               |  2 +-
 sdks/go/pkg/beam/model/pipeline_v1/beam_runner_api.pb.go |  6 +++---
 sdks/go/pkg/beam/pardo.go                                |  4 ++--
 sdks/go/pkg/beam/pardo_test.go                           |  2 +-
 sdks/go/pkg/beam/runners/dataflow/dataflow.go            |  2 +-
 sdks/go/pkg/beam/runners/universal/runnerlib/stage.go    |  2 +-
 sdks/go/pkg/beam/runners/vet/vet.go                      |  4 ++--
 sdks/go/pkg/beam/transforms/stats/quantiles_test.go      |  2 +-
 sdks/go/test/integration/integration.go                  | 14 +++++++-------
 sdks/go/test/integration/xlang/expansion_test.go         |  2 +-
 sdks/go/test/regression/coders/fromyaml/fromyaml.go      |  4 ++--
 32 files changed, 53 insertions(+), 53 deletions(-)

diff --git a/sdks/go/container/boot.go b/sdks/go/container/boot.go
index 7577f148845..03e5dd2485f 100644
--- a/sdks/go/container/boot.go
+++ b/sdks/go/container/boot.go
@@ -135,7 +135,7 @@ func getGoWorkerArtifactName(artifacts []*pipepb.ArtifactInformation) (string, e
 				return name, nil
 			}
 		}
-		// TODO(BEAM-13647): Remove legacy hack once aged out.
+		// TODO(Issue 21459): Remove legacy hack once aged out.
 		for _, a := range artifacts {
 			n, _ := artifact.MustExtractFilePayload(a)
 			if n == worker {
diff --git a/sdks/go/pkg/beam/artifact/materialize.go b/sdks/go/pkg/beam/artifact/materialize.go
index 3604675a1a1..0bcf171d59d 100644
--- a/sdks/go/pkg/beam/artifact/materialize.go
+++ b/sdks/go/pkg/beam/artifact/materialize.go
@@ -55,8 +55,8 @@ const (
 // present and uncorrupted. It interprets each artifact name as a relative
 // path under the dest directory. It does not retrieve valid artifacts already
 // present.
-// TODO(BEAM-9577): Return a mapping of filename to dependency, rather than []*jobpb.ArtifactMetadata.
-// TODO(BEAM-9577): Leverage richness of roles rather than magic names to understand artifacts.
+// TODO(Issue 20267): Return a mapping of filename to dependency, rather than []*jobpb.ArtifactMetadata.
+// TODO(Issue 20267): Leverage richness of roles rather than magic names to understand artifacts.
 func Materialize(ctx context.Context, endpoint string, dependencies []*pipepb.ArtifactInformation, rt string, dest string) ([]*pipepb.ArtifactInformation, error) {
 	if len(dependencies) > 0 {
 		return newMaterialize(ctx, endpoint, dependencies, dest)
diff --git a/sdks/go/pkg/beam/core/graph/coder/coder.go b/sdks/go/pkg/beam/core/graph/coder/coder.go
index 5047f74a5d6..64bf69e0a8f 100644
--- a/sdks/go/pkg/beam/core/graph/coder/coder.go
+++ b/sdks/go/pkg/beam/core/graph/coder/coder.go
@@ -188,7 +188,7 @@ const (
 	// It requires special handling in translation to the model pipeline in the latter case
 	// to add the incoming index for each input.
 	//
-	// TODO(BEAM-490): once this JIRA is done, this coder should become the new thing.
+	// TODO(Issue 18032): once this JIRA is done, this coder should become the new thing.
 	CoGBK Kind = "CoGBK"
 )
 
@@ -347,7 +347,7 @@ func NewT(c *Coder, w *WindowCoder) *Coder {
 		panic("window must not be nil")
 	}
 
-	// TODO(BEAM-10660): Implement proper timer support.
+	// TODO(Issue 20510): Implement proper timer support.
 	return &Coder{
 		Kind: Timer,
 		T: typex.New(reflect.TypeOf((*struct {
diff --git a/sdks/go/pkg/beam/core/graph/coder/row.go b/sdks/go/pkg/beam/core/graph/coder/row.go
index e08194acd16..26b38b88dfc 100644
--- a/sdks/go/pkg/beam/core/graph/coder/row.go
+++ b/sdks/go/pkg/beam/core/graph/coder/row.go
@@ -186,7 +186,7 @@ func ReadRowHeader(r io.Reader) (int, []byte, error) {
 // and can be skipped in decoding.
 func IsFieldNil(nils []byte, f int) bool {
 	i, b := f/8, f%8
-	// BEAM-13081: The row header can elide trailing 0 bytes,
+	// Issue 21232: The row header can elide trailing 0 bytes,
 	// and we shouldn't care if there are trailing 0 bytes when doing a lookup.
 	return i < len(nils) && len(nils) != 0 && (nils[i]>>uint8(b))&0x1 == 1
 }
diff --git a/sdks/go/pkg/beam/core/graph/coder/row_test.go b/sdks/go/pkg/beam/core/graph/coder/row_test.go
index c9892e459eb..00ec6133acb 100644
--- a/sdks/go/pkg/beam/core/graph/coder/row_test.go
+++ b/sdks/go/pkg/beam/core/graph/coder/row_test.go
@@ -864,7 +864,7 @@ func TestSchemaProviderInterface(t *testing.T) {
 }
 
 func TestRowHeader_TrailingZeroBytes(t *testing.T) {
-	// BEAM-13081: The row header should elide trailing 0 bytes.
+	// Issue 21232: The row header should elide trailing 0 bytes.
 	// But be tolerant of trailing 0 bytes.
 
 	const count = 255
diff --git a/sdks/go/pkg/beam/core/graph/mtime/time.go b/sdks/go/pkg/beam/core/graph/mtime/time.go
index 26a3dab66a4..cdcf4b82f36 100644
--- a/sdks/go/pkg/beam/core/graph/mtime/time.go
+++ b/sdks/go/pkg/beam/core/graph/mtime/time.go
@@ -37,7 +37,7 @@ const (
 
 	// EndOfGlobalWindowTime is the timestamp at the end of the global window. It
 	// is a day before the max timestamp.
-	// TODO(BEAM-4179) Use GLOBAL_WINDOW_MAX_TIMESTAMP_MILLIS from the Runner API constants
+	// TODO(Issue 18951) Use GLOBAL_WINDOW_MAX_TIMESTAMP_MILLIS from the Runner API constants
 	EndOfGlobalWindowTime = MaxTimestamp - 24*60*60*1000
 
 	// ZeroTimestamp is the default zero value time. It corresponds to the unix epoch.
diff --git a/sdks/go/pkg/beam/core/runtime/exec/coder_test.go b/sdks/go/pkg/beam/core/runtime/exec/coder_test.go
index 66121e255b4..d21708aa749 100644
--- a/sdks/go/pkg/beam/core/runtime/exec/coder_test.go
+++ b/sdks/go/pkg/beam/core/runtime/exec/coder_test.go
@@ -188,7 +188,7 @@ func TestIterableCoder(t *testing.T) {
 	}
 }
 
-// TODO(BEAM-10660): Update once proper timer support is added
+// TODO(Issue 20510): Update once proper timer support is added
 func TestTimerCoder(t *testing.T) {
 	var buf bytes.Buffer
 	tCoder := coder.NewT(coder.NewVarInt(), coder.NewGlobalWindow())
diff --git a/sdks/go/pkg/beam/core/runtime/exec/cogbk.go b/sdks/go/pkg/beam/core/runtime/exec/cogbk.go
index 7107118db7c..ac94869354e 100644
--- a/sdks/go/pkg/beam/core/runtime/exec/cogbk.go
+++ b/sdks/go/pkg/beam/core/runtime/exec/cogbk.go
@@ -23,7 +23,7 @@ import (
 	"github.com/apache/beam/sdks/v2/go/pkg/beam/internal/errors"
 )
 
-// TODO(BEAM-490): This file contains support for the handling of CoGBK
+// TODO(Issue 18032): This file contains support for the handling of CoGBK
 // over the model pipeline. Once it's a primitive, the translation will
 // no longer be needed. See graphx/cogbk.go for details.
 
diff --git a/sdks/go/pkg/beam/core/runtime/exec/combine.go b/sdks/go/pkg/beam/core/runtime/exec/combine.go
index 0f42e774c8c..59e808513a7 100644
--- a/sdks/go/pkg/beam/core/runtime/exec/combine.go
+++ b/sdks/go/pkg/beam/core/runtime/exec/combine.go
@@ -337,7 +337,7 @@ func (n *LiftedCombine) Up(ctx context.Context) error {
 	if err := n.Combine.Up(ctx); err != nil {
 		return err
 	}
-	// TODO(BEAM-4468): replace with some better implementation
+	// TODO(Issue 18944): replace with some better implementation
 	// once adding dependencies is easier.
 	// Arbitrary limit until a broader improvement can be demonstrated.
 	const cacheMax = 2000
diff --git a/sdks/go/pkg/beam/core/runtime/exec/datasource.go b/sdks/go/pkg/beam/core/runtime/exec/datasource.go
index 473c93596ba..5e7902f4dc6 100644
--- a/sdks/go/pkg/beam/core/runtime/exec/datasource.go
+++ b/sdks/go/pkg/beam/core/runtime/exec/datasource.go
@@ -134,7 +134,7 @@ func (n *DataSource) Process(ctx context.Context) error {
 	case coder.IsCoGBK(c):
 		cp = MakeElementDecoder(c.Components[0])
 
-		// TODO(BEAM-490): Support multiple value streams (coder components) with
+		// TODO(Issue 18032): Support multiple value streams (coder components) with
 		// with CoGBK.
 		cvs = []ElementDecoder{MakeElementDecoder(c.Components[1])}
 	default:
@@ -472,7 +472,7 @@ func (n *DataSource) Split(splits []int64, frac float64, bufSize int64) (SplitRe
 		return SplitResult{PI: s, RI: s + 1}, nil
 	}
 
-	// TODO(BEAM-10579) Eventually encode elements with the splittable
+	// TODO(Issue 20343) Eventually encode elements with the splittable
 	// unit's input coder instead of the DataSource's coder.
 	encodeElms := n.makeEncodeElms()
 
diff --git a/sdks/go/pkg/beam/core/runtime/exec/dynsplit_test.go b/sdks/go/pkg/beam/core/runtime/exec/dynsplit_test.go
index bd2835fe2ff..f64b718698b 100644
--- a/sdks/go/pkg/beam/core/runtime/exec/dynsplit_test.go
+++ b/sdks/go/pkg/beam/core/runtime/exec/dynsplit_test.go
@@ -110,7 +110,7 @@ func TestDynamicSplit(t *testing.T) {
 
 			// Validate split elements are encoded correctly by decoding them
 			// with the input coder to the path.
-			// TODO(BEAM-10579) Switch to using splittable unit's input coder
+			// TODO(Issue 20343) Switch to using splittable unit's input coder
 			// once that is implemented.
 			p, err := decodeDynSplitElm(splitRes.split.PS[0], cdr)
 			if err != nil {
diff --git a/sdks/go/pkg/beam/core/runtime/exec/sdf.go b/sdks/go/pkg/beam/core/runtime/exec/sdf.go
index a9062d2ae28..743e74ba755 100644
--- a/sdks/go/pkg/beam/core/runtime/exec/sdf.go
+++ b/sdks/go/pkg/beam/core/runtime/exec/sdf.go
@@ -313,7 +313,7 @@ func (n *TruncateSizedRestriction) ProcessElement(ctx context.Context, elm *Full
 	// For the main element, the way we fill it out depends on whether the input element
 	// is a KV or single-element. Single-elements might have been lifted out of
 	// their FullValue if they were decoded, so we need to have a case for that.
-	// TODO(BEAM-9798): Optimize this so it's decided in exec/translate.go
+	// TODO(Issue 20196): Optimize this so it's decided in exec/translate.go
 	// instead of checking per-element.
 	if e, ok := mainElm.Elm.(*FullValue); ok {
 		mainElm = e
@@ -487,7 +487,7 @@ func (n *ProcessSizedElementsAndRestrictions) ProcessElement(_ context.Context,
 	// is a KV or single-element. Single-elements might have been lifted out of
 	// their FullValue if they were decoded, so we need to have a case for that.
 	// Also, we use the the top-level windows and timestamp.
-	// TODO(BEAM-9798): Optimize this so it's decided in exec/translate.go
+	// TODO(Issue 20196): Optimize this so it's decided in exec/translate.go
 	// instead of checking per-element.
 	if userElm, ok := elm.Elm.(*FullValue).Elm.(*FullValue); ok {
 		mainIn.Key = FullValue{
diff --git a/sdks/go/pkg/beam/core/runtime/exec/translate.go b/sdks/go/pkg/beam/core/runtime/exec/translate.go
index c5b1cd0954a..d3cda1403ba 100644
--- a/sdks/go/pkg/beam/core/runtime/exec/translate.go
+++ b/sdks/go/pkg/beam/core/runtime/exec/translate.go
@@ -464,7 +464,7 @@ func (b *builder) makeLink(from string, id linkID) (Node, error) {
 
 					input := unmarshalKeyedValues(transform.GetInputs())
 					for i := 1; i < len(input); i++ {
-						// TODO(BEAM-3305) Handle ViewFns for side inputs
+						// TODO(Issue 18602) Handle ViewFns for side inputs
 
 						ec, wc, err := b.makeCoderForPCollection(input[i])
 						if err != nil {
diff --git a/sdks/go/pkg/beam/core/runtime/graphx/coder.go b/sdks/go/pkg/beam/core/runtime/graphx/coder.go
index e70567d705b..358beaa46ac 100644
--- a/sdks/go/pkg/beam/core/runtime/graphx/coder.go
+++ b/sdks/go/pkg/beam/core/runtime/graphx/coder.go
@@ -73,7 +73,7 @@ func knownStandardCoders() []string {
 		urnIntervalWindow,
 		urnRowCoder,
 		urnNullableCoder,
-		// TODO(BEAM-10660): Add urnTimerCoder once finalized.
+		// TODO(Issue 20510): Add urnTimerCoder once finalized.
 	}
 }
 
@@ -230,7 +230,7 @@ func (b *CoderUnmarshaller) makeCoder(id string, c *pipepb.Coder) (*coder.Coder,
 			kind = coder.CoGBK
 			root = typex.CoGBKType
 
-			// TODO(BEAM-490): If CoGBK with > 1 input, handle as special GBK. We expect
+			// TODO(Issue 18032): If CoGBK with > 1 input, handle as special GBK. We expect
 			// it to be encoded as CoGBK<K,LP<CoGBKList<V,W,..>>>. Remove this handling once
 			// CoGBK has a first-class representation.
 
@@ -489,7 +489,7 @@ func (b *CoderMarshaller) Add(c *coder.Coder) (string, error) {
 		}
 		value := comp[1]
 		if len(comp) > 2 {
-			// TODO(BEAM-490): don't inject union coder for CoGBK.
+			// TODO(Issue 18032): don't inject union coder for CoGBK.
 
 			union := b.internBuiltInCoder(urnCoGBKList, comp[1:]...)
 			value = b.internBuiltInCoder(urnLengthPrefixCoder, union)
@@ -537,7 +537,7 @@ func (b *CoderMarshaller) Add(c *coder.Coder) (string, error) {
 		}
 		return b.internRowCoder(s), nil
 
-	// TODO(BEAM-10660): Handle coder.Timer support.
+	// TODO(Issue 20510): Handle coder.Timer support.
 
 	default:
 		err := errors.Errorf("unexpected coder kind: %v", c.Kind)
diff --git a/sdks/go/pkg/beam/core/runtime/graphx/cogbk.go b/sdks/go/pkg/beam/core/runtime/graphx/cogbk.go
index 4c7217326ea..9de8c41d549 100644
--- a/sdks/go/pkg/beam/core/runtime/graphx/cogbk.go
+++ b/sdks/go/pkg/beam/core/runtime/graphx/cogbk.go
@@ -26,7 +26,7 @@ import (
 
 // CoGBK support
 //
-// TODO(BEAM-490): CoGBK is not a supported model primitive, so similarly to other
+// TODO(Issue 18032): CoGBK is not a supported model primitive, so similarly to other
 // SDKs, a translation into GBK is performed to run on portable runners. Due to
 // various constraints and to preserve CoGBK as a first-class concept in areas
 // such as type-checking and for non-portability runners, the Go translation is
diff --git a/sdks/go/pkg/beam/core/runtime/graphx/dataflow.go b/sdks/go/pkg/beam/core/runtime/graphx/dataflow.go
index e2eec3b5bcc..3097086d9d7 100644
--- a/sdks/go/pkg/beam/core/runtime/graphx/dataflow.go
+++ b/sdks/go/pkg/beam/core/runtime/graphx/dataflow.go
@@ -140,7 +140,7 @@ func EncodeCoderRef(c *coder.Coder) (*CoderRef, error) {
 
 		value := refs[1]
 		if len(c.Components) > 2 {
-			// TODO(BEAM-490): don't inject union coder for CoGBK.
+			// TODO(Issue 18032): don't inject union coder for CoGBK.
 
 			union := &CoderRef{Type: cogbklistType, Components: refs[1:]}
 			value = &CoderRef{Type: lengthPrefixType, Components: []*CoderRef{union}}
@@ -252,7 +252,7 @@ func DecodeCoderRef(c *CoderRef) (*coder.Coder, error) {
 			kind = coder.CoGBK
 			root = typex.CoGBKType
 
-			// TODO(BEAM-490): If CoGBK with > 1 input, handle as special GBK. We expect
+			// TODO(Issue 18032): If CoGBK with > 1 input, handle as special GBK. We expect
 			// it to be encoded as CoGBK<K,LP<Union<V,W,..>>. Remove this handling once
 			// CoGBK has a first-class representation.
 
diff --git a/sdks/go/pkg/beam/core/runtime/graphx/translate.go b/sdks/go/pkg/beam/core/runtime/graphx/translate.go
index cb42da25397..4cfde4e48b6 100644
--- a/sdks/go/pkg/beam/core/runtime/graphx/translate.go
+++ b/sdks/go/pkg/beam/core/runtime/graphx/translate.go
@@ -91,8 +91,8 @@ func goCapabilities() []string {
 		URNMultiCore,
 		URNTruncate,
 		URNWorkerStatus,
-		URNMonitoringInfoShortID,
-		// TOOD(BEAM-9614): Make this versioned.
+    URNMonitoringInfoShortID,
+		// TOOD(Issue 20287): Make this versioned.
 		"beam:version:sdk_base:go",
 	}
 	return append(capabilities, knownStandardCoders()...)
@@ -595,7 +595,7 @@ func (m *marshaller) expandCrossLanguage(namedEdge NamedEdge) (string, error) {
 }
 
 func (m *marshaller) expandCoGBK(edge NamedEdge) (string, error) {
-	// TODO(BEAM-490): replace once CoGBK is a primitive. For now, we have to translate
+	// TODO(Issue 18032): replace once CoGBK is a primitive. For now, we have to translate
 	// CoGBK with multiple PCollections as described in cogbk.go.
 	handleErr := func(err error) (string, error) {
 		return "", errors.Wrapf(err, "failed to expand CoGBK transform for edge: %v", edge)
diff --git a/sdks/go/pkg/beam/core/runtime/harness/datamgr.go b/sdks/go/pkg/beam/core/runtime/harness/datamgr.go
index dd4d26e9a11..91e55fb89e6 100644
--- a/sdks/go/pkg/beam/core/runtime/harness/datamgr.go
+++ b/sdks/go/pkg/beam/core/runtime/harness/datamgr.go
@@ -524,7 +524,7 @@ func (w *dataWriter) Close() error {
 			{
 				InstructionId: string(w.id.instID),
 				TransformId:   w.id.ptransformID,
-				// TODO(BEAM-13142): Set IsLast true on final flush instead of w/empty sentinel?
+				// TODO(Issue 21164): Set IsLast true on final flush instead of w/empty sentinel?
 				// Empty data == sentinel
 				IsLast: true,
 			},
diff --git a/sdks/go/pkg/beam/core/runtime/harness/monitoring.go b/sdks/go/pkg/beam/core/runtime/harness/monitoring.go
index ef6fbc1d1fc..ffffe158820 100644
--- a/sdks/go/pkg/beam/core/runtime/harness/monitoring.go
+++ b/sdks/go/pkg/beam/core/runtime/harness/monitoring.go
@@ -194,7 +194,7 @@ func monitoring(p *exec.Plan, store *metrics.Store, supportShortID bool) ([]*pip
 			panic(err)
 		}
 
-		// TODO(BEAM-9934): This metric should account for elements in multiple windows.
+		// TODO(Issue 20204): This metric should account for elements in multiple windows.
 		payloads[getShortID(metrics.PCollectionLabels(pcol.ID), metricsx.UrnElementCount)] = payload
 
 		if !supportShortID {
diff --git a/sdks/go/pkg/beam/core/util/jsonx/jsonx.go b/sdks/go/pkg/beam/core/util/jsonx/jsonx.go
index d66acea009f..e6559baf472 100644
--- a/sdks/go/pkg/beam/core/util/jsonx/jsonx.go
+++ b/sdks/go/pkg/beam/core/util/jsonx/jsonx.go
@@ -15,7 +15,7 @@
 
 // Package jsonx contains utilities for working with JSON encoded data.
 //
-// TODO(BEAM-9616): Delete this package once the SDK defaults to schemas.
+// TODO(Issue 20271): Delete this package once the SDK defaults to schemas.
 package jsonx
 
 import (
diff --git a/sdks/go/pkg/beam/io/textio/textio.go b/sdks/go/pkg/beam/io/textio/textio.go
index 7c4a8d3b725..e1b2ebfc92c 100644
--- a/sdks/go/pkg/beam/io/textio/textio.go
+++ b/sdks/go/pkg/beam/io/textio/textio.go
@@ -109,7 +109,7 @@ func expandFn(ctx context.Context, glob string, emit func(string)) error {
 }
 
 // sizeFn pairs a filename with the size of that file in bytes.
-// TODO(BEAM-11109): Once CreateInitialRestriction supports Context params and
+// TODO(Issue 20607): Once CreateInitialRestriction supports Context params and
 // error return values, this can be done in readSdfFn.CreateInitialRestriction.
 func sizeFn(ctx context.Context, filename string) (string, int64, error) {
 	fs, err := filesystem.New(ctx, filename)
diff --git a/sdks/go/pkg/beam/io/xlang/kafkaio/kafka.go b/sdks/go/pkg/beam/io/xlang/kafkaio/kafka.go
index 5871eeaf4e8..2a96b6f71db 100644
--- a/sdks/go/pkg/beam/io/xlang/kafkaio/kafka.go
+++ b/sdks/go/pkg/beam/io/xlang/kafkaio/kafka.go
@@ -41,7 +41,7 @@
 //    - Reference Class: org.apache.beam.sdk.io.kafka.KafkaIO
 package kafkaio
 
-// TODO(BEAM-12492): Implement an API for specifying Kafka type serializers and
+// TODO(Issue 21000): Implement an API for specifying Kafka type serializers and
 // deserializers.
 
 import (
diff --git a/sdks/go/pkg/beam/model/pipeline_v1/beam_runner_api.pb.go b/sdks/go/pkg/beam/model/pipeline_v1/beam_runner_api.pb.go
index f7f9be4940f..9037c468134 100644
--- a/sdks/go/pkg/beam/model/pipeline_v1/beam_runner_api.pb.go
+++ b/sdks/go/pkg/beam/model/pipeline_v1/beam_runner_api.pb.go
@@ -933,11 +933,11 @@ const (
 	//
 	// Schema types are mapped to coders as follows:
 	//   AtomicType:
-	//     BYTE:      not yet a standard coder (BEAM-7996)
-	//     INT16:     not yet a standard coder (BEAM-7996)
+	//     BYTE:      not yet a standard coder (Issue 19815)
+	//     INT16:     not yet a standard coder (Issue 19815)
 	//     INT32:     beam:coder:varint:v1
 	//     INT64:     beam:coder:varint:v1
-	//     FLOAT:     not yet a standard coder (BEAM-7996)
+	//     FLOAT:     not yet a standard coder (Issue 19815)
 	//     DOUBLE:    beam:coder:double:v1
 	//     STRING:    beam:coder:string_utf8:v1
 	//     BOOLEAN:   beam:coder:bool:v1
diff --git a/sdks/go/pkg/beam/pardo_test.go b/sdks/go/pkg/beam/pardo_test.go
index e124b7f2af9..bc153da2d6f 100644
--- a/sdks/go/pkg/beam/pardo_test.go
+++ b/sdks/go/pkg/beam/pardo_test.go
@@ -146,7 +146,7 @@ func TestParDoSideInputValidation(t *testing.T) {
 		wFn       *window.Fn
 		isBounded bool
 	}{
-		// TODO(BEAM-14501): Re-enable this test case once proper streaming testing support is finished.
+		// TODO(Issue 21596): Re-enable this test case once proper streaming testing support is finished.
 		// {
 		// 	"global window unbounded",
 		// 	window.NewGlobalWindows(),
diff --git a/sdks/go/pkg/beam/runners/dataflow/dataflow.go b/sdks/go/pkg/beam/runners/dataflow/dataflow.go
index 761288716a6..4c1ceccf312 100644
--- a/sdks/go/pkg/beam/runners/dataflow/dataflow.go
+++ b/sdks/go/pkg/beam/runners/dataflow/dataflow.go
@@ -76,7 +76,7 @@ var (
 	workerZone             = flag.String("worker_zone", "", "Dataflow worker zone (optional)")
 	dataflowServiceOptions = flag.String("dataflow_service_options", "", "Comma separated list of additional job modes and configurations (optional)")
 	flexRSGoal             = flag.String("flexrs_goal", "", "Which Flexible Resource Scheduling mode to run in (optional)")
-	// TODO(BEAM-14512) Turn this on once TO_STRING is implemented
+	// TODO(Issue 21604) Turn this on once TO_STRING is implemented
 	// enableHotKeyLogging    = flag.Bool("enable_hot_key_logging", false, "Specifies that when a hot key is detected in the pipeline, the literal, human-readable key is printed in the user's Cloud Logging project (optional).")
 
 	// Streaming update flags
diff --git a/sdks/go/pkg/beam/runners/universal/runnerlib/stage.go b/sdks/go/pkg/beam/runners/universal/runnerlib/stage.go
index b1cd16324c8..5cf360e3eb7 100644
--- a/sdks/go/pkg/beam/runners/universal/runnerlib/stage.go
+++ b/sdks/go/pkg/beam/runners/universal/runnerlib/stage.go
@@ -83,7 +83,7 @@ func StageViaPortableApi(ctx context.Context, cc *grpc.ClientConn, binary, st st
 
 		case *jobpb.ArtifactRequestWrapper_GetArtifact:
 			switch typeUrn := request.GetArtifact.Artifact.TypeUrn; typeUrn {
-			// TODO(BEAM-13647): Legacy Type URN. If requested, provide the binary.
+			// TODO(Issue 21459): Legacy Type URN. If requested, provide the binary.
 			// To be removed later in 2022, once thoroughly obsolete.
 			case graphx.URNArtifactGoWorker:
 				if err := StageFile(binary, stream); err != nil {
diff --git a/sdks/go/pkg/beam/runners/vet/vet.go b/sdks/go/pkg/beam/runners/vet/vet.go
index 79290bbbdf5..37cd7406361 100644
--- a/sdks/go/pkg/beam/runners/vet/vet.go
+++ b/sdks/go/pkg/beam/runners/vet/vet.go
@@ -21,7 +21,7 @@
 // can use this as a sanity check on whether a given pipeline avoids known
 // performance bottlenecks.
 //
-// TODO(BEAM-7374): Add usage documentation.
+// TODO(Issue 19402): Add usage documentation.
 package vet
 
 import (
@@ -503,7 +503,7 @@ func (e *Eval) Bytes() []byte {
 // is used.
 func (e *Eval) extractGraphFn(fn *graph.Fn) {
 	if fn.DynFn != nil {
-		// TODO(BEAM-7375) handle dynamics if necessary (probably not since it's got general function handling)
+		// TODO(Issue 19401) handle dynamics if necessary (probably not since it's got general function handling)
 		e.diag(" dynamic function")
 		return
 	}
diff --git a/sdks/go/pkg/beam/transforms/stats/quantiles_test.go b/sdks/go/pkg/beam/transforms/stats/quantiles_test.go
index b2440da827d..b4c370da23a 100644
--- a/sdks/go/pkg/beam/transforms/stats/quantiles_test.go
+++ b/sdks/go/pkg/beam/transforms/stats/quantiles_test.go
@@ -30,7 +30,7 @@ func init() {
 	beam.RegisterFunction(weightedElementToKv)
 
 	// In practice, this runs faster than plain reflection.
-	// TODO(BEAM-9616): Remove once collisions don't occur for starcgen over test code and an equivalent is generated for us.
+	// TODO(Issue 20271): Remove once collisions don't occur for starcgen over test code and an equivalent is generated for us.
 	reflectx.RegisterFunc(reflect.ValueOf(less).Type(), func(_ interface{}) reflectx.Func {
 		return newIntLess()
 	})
diff --git a/sdks/go/test/integration/integration.go b/sdks/go/test/integration/integration.go
index 2af95303304..9f3c26c8b20 100644
--- a/sdks/go/test/integration/integration.go
+++ b/sdks/go/test/integration/integration.go
@@ -73,9 +73,9 @@ var directFilters = []string{
 	"TestPanes",
 	// The direct runner does not support the TestStream primitive
 	"TestTestStream.*",
-	// (BEAM-13075): The direct runner does not support windowed side inputs
+	// (Issue 21130): The direct runner does not support windowed side inputs
 	"TestValidateWindowedSideInputs",
-	// (BEAM-13075): The direct runner does not currently support multimap side inputs
+	// (Issue 21130): The direct runner does not currently support multimap side inputs
 	"TestParDoMultiMapSideInput",
 	"TestLargeWordcount_Loopback",
 	// The direct runner does not support self-checkpointing
@@ -92,7 +92,7 @@ var portableFilters = []string{
 	// The trigger and pane tests uses TestStream
 	"TestTrigger.*",
 	"TestPanes",
-	// TODO(BEAM-12797): Python portable runner times out on Kafka reads.
+	// TODO(Issue 21058): Python portable runner times out on Kafka reads.
 	"TestKafkaIO.*",
 	// TODO(BEAM-13215): GCP IOs currently do not work in non-Dataflow portable runners.
 	"TestBigQueryIO.*",
@@ -105,9 +105,9 @@ var portableFilters = []string{
 }
 
 var flinkFilters = []string{
-	// TODO(BEAM-11500): Flink tests timing out on reads.
+	// TODO(Issue 20723): Flink tests timing out on reads.
 	"TestXLang_Combine.*",
-	// TODO(BEAM-12815): Test fails on post commits: "Insufficient number of network buffers".
+	// TODO(Issue 21094): Test fails on post commits: "Insufficient number of network buffers".
 	"TestXLang_Multi",
 	"TestDebeziumIO_BasicRead",
 	// TODO(BEAM-13215): GCP IOs currently do not work in non-Dataflow portable runners.
@@ -121,7 +121,7 @@ var flinkFilters = []string{
 }
 
 var samzaFilters = []string{
-	// TODO(BEAM-12608): Samza tests invalid encoding.
+	// TODO(Issue 20987): Samza tests invalid encoding.
 	"TestReshuffle",
 	"TestReshuffleKV",
 	// The Samza runner does not support the TestStream primitive
@@ -129,7 +129,7 @@ var samzaFilters = []string{
 	// The trigger and pane tests uses TestStream
 	"TestTrigger.*",
 	"TestPanes",
-	// TODO(BEAM-13006): Samza doesn't yet support post job metrics, used by WordCount
+	// TODO(Issue 21244): Samza doesn't yet support post job metrics, used by WordCount
 	"TestWordCount.*",
 	// TODO(BEAM-13215): GCP IOs currently do not work in non-Dataflow portable runners.
 	"TestBigQueryIO.*",
diff --git a/sdks/go/test/integration/xlang/expansion_test.go b/sdks/go/test/integration/xlang/expansion_test.go
index 113e1c53784..3bf30e9f8d0 100644
--- a/sdks/go/test/integration/xlang/expansion_test.go
+++ b/sdks/go/test/integration/xlang/expansion_test.go
@@ -24,7 +24,7 @@ import (
 )
 
 const (
-	// TODO(BEAM-13505): Select the most recent Beam release instead of a hard-coded
+	// TODO(Issue 21279): Select the most recent Beam release instead of a hard-coded
 	// string.
 	beamVersion  = "2.34.0"
 	gradleTarget = ":sdks:java:io:expansion-service:runExpansionService"
diff --git a/sdks/go/test/regression/coders/fromyaml/fromyaml.go b/sdks/go/test/regression/coders/fromyaml/fromyaml.go
index 199ff4e2a91..263c772b93c 100644
--- a/sdks/go/test/regression/coders/fromyaml/fromyaml.go
+++ b/sdks/go/test/regression/coders/fromyaml/fromyaml.go
@@ -50,7 +50,7 @@ var unimplementedCoders = map[string]bool{
 
 var filteredCases = []struct{ filter, reason string }{
 	{"logical", "BEAM-9615: Support logical types"},
-	{"30ea5a25-dcd8-4cdb-abeb-5332d15ab4b9", "BEAM-13043: Support encoding position."},
+	{"30ea5a25-dcd8-4cdb-abeb-5332d15ab4b9", "Issue 21206: Support encoding position."},
 }
 
 // Coder is a representation a serialized beam coder.
@@ -89,7 +89,7 @@ func (s *Spec) testStandardCoder() (err error) {
 		return nil
 	}
 	if s.Coder.Urn == "beam:coder:state_backed_iterable:v1" {
-		log.Printf("skipping unimplemented test coverage for beam:coder:state_backed_iterable:v1. BEAM-13801")
+		log.Printf("skipping unimplemented test coverage for beam:coder:state_backed_iterable:v1. Issue 21324")
 		return nil
 	}
 	for _, c := range filteredCases {
diff --git a/sdks/go/pkg/beam/pardo.go b/sdks/go/pkg/beam/pardo.go
index 86fcdaf1ea0..46fec98e79f 100644
--- a/sdks/go/pkg/beam/pardo.go
+++ b/sdks/go/pkg/beam/pardo.go
@@ -65,8 +65,8 @@ func TryParDo(s Scope, dofn interface{}, col PCollection, opts ...Option) ([]PCo
 			return nil, fmt.Errorf("main input is global windowed in DoFn %v but side input %v is not, cannot map windows correctly. Consider re-windowing the side input PCollection before use", fn, i)
 		}
 		if (sideWfn.Kind == window.GlobalWindows) && !sideNode.Bounded() {
-			// TODO(BEAM-14501): Replace this warning with an error return when proper streaming test functions have been added.
-			log.Warnf(context.Background(), "side input %v is global windowed in DoFn %v but is unbounded, DoFn will block until end of Global Window. Consider windowing your unbounded side input PCollection before use. This will cause your pipeline to fail in a future release, see BEAM-14501 for details", i, fn)
+			// TODO(Issue 21596): Replace this warning with an error return when proper streaming test functions have been added.
+			log.Warnf(context.Background(), "side input %v is global windowed in DoFn %v but is unbounded, DoFn will block until end of Global Window. Consider windowing your unbounded side input PCollection before use. This will cause your pipeline to fail in a future release, see Issue 21596 for details", i, fn)
 		}
 		in = append(in, s.Input.n)
 	}